@@ -1,10 +1,9 @@
-# -*- coding: utf-8 -*-
 from plone.app.blocks.interfaces import IAfterTileRenderEvent
 from plone.app.blocks.interfaces import IBeforeTileRenderEvent
 from zope.interface import implementer
 
 
-class BaseTileRenderEvent(object):
+class BaseTileRenderEvent:
     def __init__(self, tile_href, tile_node):
         self.tile_href = tile_href
         self.tile_node = tile_node
