@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from plone.app.blocks.interfaces import IBlocksTransformEnabled
 from plone.app.blocks.layoutbehavior import ILayoutAware
 from plone.app.layout.globals.interfaces import IViewView
@@ -14,7 +13,7 @@ from zope.interface import implementer
 import os
 
 
-ERROR_LAYOUT = u"""
+ERROR_LAYOUT = """
 <!DOCTYPE html>
 <html lang="en" data-layout="./@@page-site-layout">
 <body>
@@ -32,7 +31,7 @@ class SiteLayoutView(BrowserView):
     index = ViewPageTemplateFile(os.path.join("templates", "main_template.pt"))
 
     def __init__(self, context, request, name="layout"):
-        super(SiteLayoutView, self).__init__(context, request)
+        super().__init__(context, request)
         self.__name__ = name
 
     def __call__(self):
@@ -57,11 +56,7 @@ class ContentLayoutView(DefaultView):
         # Here we skip legacy portal_transforms and call plone.outputfilters
         # directly by purpose
         filters = [f for _, f in getAdapters((self.context, self.request), IFilter)]
-        result = apply_filters(filters, layout)
-        if not self.request.response.getHeader('Content-Type'):
-            # Needed since Plone 5.2.10.1/6.0.0.1 with Zope security fix.
-            self.request.response.setHeader('Content-Type', 'text/html')
-        return result
+        return apply_filters(filters, layout)
 
 
 @implementer(IBlocksTransformEnabled)
@@ -80,7 +75,7 @@ class ContentLayoutPreview(ContentLayoutView):
             alsoProvides(self.request, IDisplayFormDrafting)
             self.context = DraftProxy(draft, self.context)
 
-        return super(ContentLayoutPreview, self).__call__()
+        return super().__call__()
 
 
 @implementer(IBlocksTransformEnabled)
@@ -101,8 +96,4 @@ class TileLayoutView(DefaultView):
         # Here we skip legacy portal_transforms and call plone.outputfilters
         # directly by purpose
         filters = [f for _, f in getAdapters((self.context, self.request), IFilter)]
-        result = apply_filters(filters, layout)
-        if not self.request.response.getHeader('Content-Type'):
-            # Needed since Plone 5.2.10.1/6.0.0.1 with Zope security fix.
-            self.request.response.setHeader('Content-Type', 'text/html')
-        return result
+        return apply_filters(filters, layout)
